==> spip_3.2.11.orig.tar.xz: plugins-dist/mots/lang/mots_ro.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=ro
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Grup important:</b>  e foarte indicat să selecţionaţi un cuvânt cheie în acest grup.',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'administratorii site-ului',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'redactorii',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'vizitatorii site-ului public când postează un mesaj într-un forum.',

	// I
	'icone_creation_groupe_mots' => 'Creaţi un nou grup de cuvinte',
	'icone_creation_mots_cles' => 'Creaţi un nou cuvânt-cheie',
	'icone_modif_groupe_mots' => 'Modificaţi acest grup de cuvinte',
	'icone_modifier_mot' => 'Modificaţi acest cuvânt-cheie',
	'icone_mots_cles' => 'Cuvinte-cheie',
	'icone_supprimer_groupe_mots' => 'Ştergeţi acest grup',
	'icone_voir_tous_mots_cles' => 'Vedeţi toate cuvintele-cheie',
	'info_articles_lies_mot' => 'Articole legate de acest cuvânt-cheie',
	'info_changer_nom_groupe' => 'Schimbaţi numele acestui grup :',
	'info_creation_mots_cles' => 'Creaţi şi configuraţi aici cuvintele-cheie de pe acest site',
	'info_dans_groupe' => 'În grupul :',
	'info_delet_mots_cles' => 'Aţi cerut ştergerea cuvântului-cheie
<b>@titre_mot@</b> (@type_mot@). Acest cuvânt-cheie fiind legat de
<b>@texte_lie@</b> vă rugăm să confirmaţi această decizie :', # MODIF
	'info_groupe_important' => 'Grup important',
	'info_modifier_mot' => 'Modificaţi cuvântul-cheie :',
	'info_mots_cles' => 'Cuvintele-cheie',
	'info_mots_cles_association' => 'Cuvintele-cheie din acest grup pot fi asociate :',
	'info_oui_suppression_mot_cle' => 'doresc să şterg definitiv acest cuvânt-cheie.',
	'info_question_mots_cles' => 'Doriţi să utilizaţi cuvintele-cheie pe site-ul dumneavoastră ?',
	'info_qui_attribue_mot_cle' => 'Cuvintele-cheie din acest grup pot fi atribuite de către :',
	'info_retirer_mot' => 'Retrageţi acest cuvânt',
	'info_retirer_mots' => 'Retrageţi toate cuvintele',
	'info_rubriques_liees_mot' => 'Rubricile legate de acest cuvânt-cheie',
	'info_selection_un_seul_mot_cle' => 'Doar <b>un singur cuvânt-cheie</b> poate fi selecţionat pe moment din acest grup.', # MODIF
	'info_supprimer_mot' => 'ştergeţi acest cuvânt',
	'info_titre_mot_cle' => 'Numele sau titlu cuvântului-cheie',
	'info_un_mot' => 'Un singur cuvânt-cheie odată',
	'item_ajout_mots_cles' => 'Autorizaţi adăugarea cuvintelor-cheie la forum-uri',
	'item_non_ajout_mots_cles' => 'Interziceţi utilizarea cuvintelor-cheie în forum-uri',
	'item_non_utiliser_config_groupe_mots_cles' => 'Nu folosiţi configurarea avansată a grupurilor de cuvinte-cheie',
	'item_non_utiliser_mots_cles' => 'Nu utilizaţi cuvintele-cheie',
	'item_utiliser_config_groupe_mots_cles' => 'Utilizaţi configurarea avansată a grupurilor de cuvinte-cheie',
	'item_utiliser_mots_cles' => 'Utilizaţi cuvintele-cheie',

	// L
	'logo_mot_cle' => 'VINIETA CUVÂNTULUI-CHEIE',

	// T
	'texte_config_groupe_mots_cles' => 'Doriţi să activaţi configurarea avansată a cuvintelor-cheie,
   indicând, de exemplu, că puteţi selecţiona un cuvânt unic
   pe grup, sau că un grup este important... ?', # MODIF
	'texte_mots_cles' => 'Cuvintele-cheie permit crearea de legături tematice între articole,
  independent de plasarea lor în rubrici. Puteţi astfel
  să îmbogăţiţi navigarea site-ului dumneavoatră, adică să utilizaţi aceste proprietăţi
  pentru a personaliza prezentarea articolelor în scheletele dumneavoastră.',
	'texte_mots_cles_dans_forum' => 'Doriţi să permiteţi utilizarea cuvintelor-cheie de către vizitatori, în forum-urile site-ului public ? (Atenţie : această opţiune este relativ complicat de folosit corect).',
	'texte_nouveau_mot' => 'Cuvânt nou',
	'titre_config_groupe_mots_cles' => 'Configuraţia grupurilor de cuvinte-cheie',
	'titre_gauche_mots_edit' => 'CUVÂNT NUMĂRUL :',
	'titre_mots_cles_dans_forum' => 'Cuvinte-cheie în forum-urile site-ului public',
	'titre_mots_tous' => 'Cuvintele-cheie',
	'titre_nouveau_groupe' => 'Grup nou',
	'titre_page_mots_tous' => 'Cuvinte-cheie'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/mots/lang/mots_ro.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=ro
// ** ne pas modifier le fichier **

return [

	// A
	'avis_conseil_selection_mot_cle' => '<b>Grup important:</b>  e foarte indicat să selecţionaţi un cuvânt cheie în acest grup.',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'administratorii site-ului',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'redactorii',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'vizitatorii site-ului public când postează un mesaj într-un forum.',

	// I
	'icone_creation_groupe_mots' => 'Creaţi un nou grup de cuvinte',
	'icone_creation_mots_cles' => 'Creaţi un nou cuvânt-cheie',
	'icone_modif_groupe_mots' => 'Modificaţi acest grup de cuvinte',
	'icone_modifier_mot' => 'Modificaţi acest cuvânt-cheie',
	'icone_mots_cles' => 'Cuvinte-cheie',
	'icone_supprimer_groupe_mots' => 'Ştergeţi acest grup',
	'icone_voir_tous_mots_cles' => 'Vedeţi toate cuvintele-cheie',
	'info_articles_lies_mot' => 'Articole legate de acest cuvânt-cheie',
	'info_changer_nom_groupe' => 'Schimbaţi numele acestui grup :',
	'info_creation_mots_cles' => 'Creaţi şi configuraţi aici cuvintele-cheie de pe acest site',
	'info_dans_groupe' => 'În grupul :',
	'info_delet_mots_cles' => 'Aţi cerut ştergerea cuvântului-cheie
<b>@titre_mot@</b> (@type_mot@). Acest cuvânt-cheie fiind legat de
<b>@texte_lie@</b> vă rugăm să confirmaţi această decizie :', # MODIF
	'info_groupe_important' => 'Grup important',
	'info_modifier_mot' => 'Modificaţi cuvântul-cheie :',
	'info_mots_cles' => 'Cuvintele-cheie',
	'info_mots_cles_association' => 'Cuvintele-cheie din acest grup pot fi asociate :',
	'info_oui_suppression_mot_cle' => 'doresc să şterg definitiv acest cuvânt-cheie.',
	'info_question_mots_cles' => 'Doriţi să utilizaţi cuvintele-cheie pe site-ul dumneavoastră ?',
	'info_qui_attribue_mot_cle' => 'Cuvintele-cheie din acest grup pot fi atribuite de către :',
	'info_retirer_mot' => 'Retrageţi acest cuvânt',
	'info_retirer_mots' => 'Retrageţi toate cuvintele',
	'info_rubriques_liees_mot' => 'Rubricile legate de acest cuvânt-cheie',
	'info_selection_un_seul_mot_cle' => 'Doar <b>un singur cuvânt-cheie</b> poate fi selecţionat pe moment din acest grup.', # MODIF
	'info_supprimer_mot' => 'ştergeţi acest cuvânt',
	'info_titre_mot_cle' => 'Numele sau titlu cuvântului-cheie',
	'info_un_mot' => 'Un singur cuvânt-cheie odată',
	'item_ajout_mots_cles' => 'Autorizaţi adăugarea cuvintelor-cheie la forum-uri',
	'item_non_ajout_mots_cles' => 'Interziceţi utilizarea cuvintelor-cheie în forum-uri',
	'item_non_utiliser_config_groupe_mots_cles' => 'Nu folosiţi configurarea avansată a grupurilor de cuvinte-cheie',
	'item_non_utiliser_mots_cles' => 'Nu utilizaţi cuvintele-cheie',
	'item_utiliser_config_groupe_mots_cles' => 'Utilizaţi configurarea avansată a grupurilor de cuvinte-cheie',
	'item_utiliser_mots_cles' => 'Utilizaţi cuvintele-cheie',

	// L
	'logo_mot_cle' => 'VINIETA CUVÂNTULUI-CHEIE',

	// T
	'texte_config_groupe_mots_cles' => 'Doriţi să activaţi configurarea avansată a cuvintelor-cheie,
   indicând, de exemplu, că puteţi selecţiona un cuvânt unic
   pe grup, sau că un grup este important... ?', # MODIF
	'texte_mots_cles' => 'Cuvintele-cheie permit crearea de legături tematice între articole,
  independent de plasarea lor în rubrici. Puteţi astfel
  să îmbogăţiţi navigarea site-ului dumneavoatră, adică să utilizaţi aceste proprietăţi
  pentru a personaliza prezentarea articolelor în scheletele dumneavoastră.',
	'texte_mots_cles_dans_forum' => 'Doriţi să permiteţi utilizarea cuvintelor-cheie de către vizitatori, în forum-urile site-ului public ? (Atenţie : această opţiune este relativ complicat de folosit corect).',
	'texte_nouveau_mot' => 'Cuvânt nou',
	'titre_config_groupe_mots_cles' => 'Configuraţia grupurilor de cuvinte-cheie',
	'titre_gauche_mots_edit' => 'CUVÂNT NUMĂRUL :',
	'titre_mots_cles_dans_forum' => 'Cuvinte-cheie în forum-urile site-ului public',
	'titre_mots_tous' => 'Cuvintele-cheie',
	'titre_nouveau_groupe' => 'Grup nou',
	'titre_page_mots_tous' => 'Cuvinte-cheie',
];
